William Dillon wdillon
Načítání teplotní mapy…

wdillon nahrál(a) do master v wdillon/mishmash

  • 262ea789d3 updating primeset and mishmash_test.go

před 5 roky

wdillon nahrál(a) do master v wdillon/mishmash

  • 5f5bdae562 updating mishmash - changed some types to remove a lot of casting from Engine(), renamed slct to selectPrime. removed some extra code from the Mishmash benchmark

před 5 roky

wdillon nahrál(a) do master v wdillon/mishmash

  • b65d469721 updating mishmash hash to match main CodeDweller branch

před 5 roky

wdillon nahrál(a) do master v wdillon/mishmash

  • c37b14540e updating tests + benchmark. found strings to be marginally faster (12500 ns/op vs []byte at ~15000 ns/op)

před 5 roky

wdillon nahrál(a) do master v wdillon/mishmash

  • e3a1552948 Merge branch 'master' of https://code.microneil.com/wdillon/mishmash
  • cb20cac2f1 changed []byte to string after finding out string indexing is faster than []byte in Go, since we're never modifying our string and only working with the accumulator we should see an improvement in speed in general
  • Porovnat 2 revizí »

před 5 roky

wdillon nahrál(a) do master v wdillon/mishmash

před 5 roky

wdillon nahrál(a) do master v wdillon/mishmash

  • 75fc6bd2db testing against CodeDweller/mishmash, minor changes in preparation of testing Golang Threatable

před 5 roky

wdillon nahrál(a) do master v wdillon/mishmash

před 5 roky

wdillon nahrál(a) do master v wdillon/mishmash

  • ba60fcb929 updated mishmash - engine returns accumulator for use with Mishmash which takes it as an optional seed. Mishmash can be seeded however desired through this mechanism as well. Added simple function to decode accumulator for ease of use when we're going to be double hashing

před 5 roky

wdillon nahrál(a) do master v wdillon/mishmash

  • 7bad662b17 updated mishmash - added second hash capabilities by converting Mishmash to a modified variadic function - takes and uses the accumulator if given

před 5 roky